.draw_recmap_us_state_ev: this function reproduces the original election cartogram from 2004 using
the cartogram output from the 2003 implementation.
Description
this function reproduces the original election cartogram from 2004 using
the cartogram output from the 2003 implementation.
Usage
.draw_recmap_us_state_ev(plot = TRUE)
Arguments
- plot
default is TRUE